# ``scout``


<p align="center">
  <img src="https://github.com/fsorrenti/scout/blob/main/assets/img/scout.jpg" width="52%"
 alt="veloce_logo"/>
</p>

<div align="center">
  
![](https://img.shields.io/badge/Python-181717?style=plastic&logo=python)
![](https://img.shields.io/badge/Author-Francesco%20Sorrenti%20-181717?style=plastic)

</div>



Hello! Welcome to `scout` (Supernova Cosmology Utilities)! This repositories provide all the codes necessary for computing the multipoles of the SNe luminosity distance and  reproduce the results in https://arxiv.org/pdf/2212.10328, https://arxiv.org/pdf/2403.17741 and https://arxiv.org/pdf/2407.07002,  together with analyses tools. 


## Example

Examples can be found in [notebooks](https://github.com/fsorrenti/scout/blob/main/notebooks). 

## Contributing and contacts

Feel free to [fork](https://github.com/fsorrenti/scout/fork) this repository to work on it; otherwise, please [raise an issue](https://github.com/fsorrenti/scout/issues) or contact [Francesco Sorrenti](mailto:francescosorrenti96@gmail.com).

## License

`scout` is released under the GPL-3 license (see [LICENSE](https://github.com/fsorrenti/scout/blob/main/LICENSE.txt)) subject to the non-commercial use condition.

     scout
     Copyright (C) 2025 Francesco Sorrenti & contributors

     This program is released under the GPL-3 license (see LICENSE.txt), subject to a non-commercial use condition.
